@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
-__version__ = "0.1.0"
 
 from .repo import Repository
-from .repo import RepoImporter
 from .repo import ImportPathError
 
 from .commands import Command
 from .commands import git_command
+from .commands import hg_command
 from .commands import default_commands
 
 from .hosts import Host
