@@ -1,36 +1,79 @@
 # -*- coding: utf-8 -*-
 """
-    This module provides a Repository and a RepoImporter. The Repository
-    allows managing a general repository via its command. A RepoImporter
-    simplifies constructing Repositories from import paths.
+    This module provides a Repository abstraction to allow a file 
+    repository to be managed on-disk, via a Pythonic API.
 """
 
 from . import hosts
 from . import commands
 import re
 
+# TODO: accept a custom RepoImporter
 class Repository(object):
     """
-    Representation of a repository which is identified by an import_path
-    , managed by a :class:`Command <commands.Command>` object, and 
-    hosted at some url.
+    Representation of a repository which is managed by a 
+    :class:`Command <commands.Command>` object, and hosted at some url.
+
+    A Repository object may be constructed from a `command` and `url`
+    directly, or a respository `import_path` can be provided which will
+    resolve the `command` or `url`, if they aren't provided.
+
+    Usage::
+        
+        from pyrepo import git_command as git
+
+        repo = Repository(command=git, 
+                          url='https://github.com/dghubble/pyrepo.git')
+
+        # autodetects the correct repository url
+        repo = Repository(command=git, 
+                          import_path='github.com/dghubble/pyrepo')
+
+        # autdetects the correct command and repository url
+        repo = Repository(import_path='github.com/dghubble/pyrepo')
+
     """
 
-    def __init__(self, identifier, url, command):
+    def __init__(self, command=None, url=None, import_path=None):
         """
-        :param str identifier: import path identifying a repository
-        :param str url: url from which the repo can be fetched
-        :param command: :class:`Command <commands.Command>` for managing 
-            the repo
+        Provide either the `command` and `url` or provide an `import_path`.
+
+        :param Command command: (optional) 
+            :class:`Command <commands.Command>` for managing
+            the repository
+        :param str url: (optional) url where the repo can be found
+        :param str import_path: (optional) import path of the repository
+            (e.g. github.com/dghubble/pyrepo)
+        :raises: ValueError, :class:`ImportPathError <ImportPathError>`
         """
-        self.identifier = identifier
-        self.url = url
-        self.command = command
+        if url is None or command is None:
+            # must resolve the import_path against hosts
+            if import_path is None:
+                raise ValueError(("Repository construction requires 1)"
+                    " a `url` and `command` or 2) an `import_path`."))
+
+            # Resolve command and url, may throw ImportPathError
+            (resCommand, resUrl) = RepoImporter().resolve(import_path)
+            self.command = command or resCommand
+            self.url = url or resUrl
+            self.import_path = import_path
+        else:
+            # url and command are both non-None, no additional checks
+            self.command = command
+            self.url = url
+            self.import_path = None  
 
     def clone(self, *args, **kwargs):
         """
-        Arguments are the same as :class:`Command.clone 
-        <commands.Command.clone>` arguments.
+        Calls :class:`Command.clone <commands.Command.clone>` with the 
+        repository `url` positional argument, followed by the given 
+        positional args and keyword kwargs.
+
+        Usage::
+
+            target_dir = os.path.expanduser('~')
+            # clone the repository into the target directory (e.g. home)
+            repo.clone(target_dir)
         """
         return self.command.clone(self.url, *args, **kwargs)
 
@@ -48,26 +91,11 @@ class Repository(object):
         """
         return self.command.tag_list(*args, **kwargs)
 
-    def ping(self, *args, **kwargs):
-        """
-        Arguments are the same as :class:`Command.ping 
-        <commands.Command.ping>` arguments.
-        """
-        return self.command.ping(*args, **kwargs)
-
 
 class RepoImporter(object):
     """
-    Utility for resolving an import path to a :class:`Repository 
-    <Repository>` object by determining the repository host, the 
-    repository command, the scheme of the repository, and with that
-    information, the remote url.
-
-    Usage::
-
-        importer = RepoImporter()
-        repo = importer.repo("github.com/dghubble/pyrepo")
-        repo.clone()
+    Utility for resolving an import path to a `url` and a
+    :class:`Command <commands.Command>`.
     """
     DEFAULT_HOSTS = hosts.default_hosts
     DEFAULT_COMMANDS = commands.default_commands
@@ -90,12 +118,12 @@ class RepoImporter(object):
     
     def resolve(self, import_path):
         """
-        Resolves an import path to a :class:`Repository 
-        <Repository>`.
+        Resolves an import path to a
+        (:class:`Command <commands.Command>`, `url`) tuple.
 
         :param str import_path: import path identifying a repository.
-        :returns: :class:`Repository <Repository>` corresponding to the 
-            import path 
+        :returns: (:class:`Command <commands.Command>`, `url`) tuple
+            corresponding to the `import_path`
         :raises: :class:`ImportPathError <ImportPathError>`
         """
         self._validate_import_path(import_path)
@@ -109,7 +137,7 @@ class RepoImporter(object):
                 .format(command_name, host.name))
         # TODO: start respecting per-host scheme
         url = self._build_url(import_path, host, None)
-        return Repository(identifier=import_path, url=url, command=command)
+        return (command, url)
 
     def _validate_import_path(self, import_path):
         if "://" in import_path:
@@ -177,8 +205,8 @@ class RepoImporter(object):
 
 class ImportPathError(Exception):
     """
-    Raised when a :class:`RepoImporter <RepoImporter>` cannot create a 
-    :class:`Repository <Repository>` object from an import path.
+    Raised when a :class:`RepoImporter <RepoImporter>` cannot resolve
+    an `import_path`.
     """
     pass
 
